Documentation
¶
Index ¶
- Constants
- func Reply(ctx *gin.Context, err error, data ...any)
- func ReplyErr(ctx *gin.Context, err error, msg ...string)
- func ReplyOk(ctx *gin.Context, data ...any)
- func ReplyWSErr(s *melody.Session, action string, msgUUID uuid.UUID, err error) error
- func ReplyWSOk(s *melody.Session, action string, msgUUID uuid.UUID, data ...any) error
- type BinUUID
- func (u BinUUID) Bytes() []byte
- func (u BinUUID) Equals(other BinUUID) bool
- func (BinUUID) GormDBDataType(db *gorm.DB, _ *schema.Field) string
- func (BinUUID) GormDataType() string
- func (u BinUUID) IsEmpty() bool
- func (u *BinUUID) IsEmptyPtr() bool
- func (u BinUUID) IsNil() bool
- func (u *BinUUID) IsNilPtr() bool
- func (u BinUUID) Length() int
- func (u BinUUID) LengthBytes() int
- func (u BinUUID) MarshalJSON() ([]byte, error)
- func (u *BinUUID) Scan(value interface{}) error
- func (u BinUUID) String() string
- func (u *BinUUID) UnmarshalJSON(data []byte) error
- func (u BinUUID) Value() (driver.Value, error)
- type Error
- type PageMoreResp
- type PageReq
- type PageReqT
- type PageResp
- type Resp
- type RespT
- type WSData
- type WsMsgType
Constants ¶
const ( MaxPageSize = 2000 DefaultPageSize = 20 DefaultPage = 1 )
const (
BINARY = "BINARY(16)"
)
Variables ¶
This section is empty.
Functions ¶
func ReplyWSErr ¶
Types ¶
type BinUUID ¶
func (BinUUID) Equals ¶
Equals returns true if bytes form of BinUUID matches other, false otherwise.
func (BinUUID) GormDBDataType ¶
GormDBDataType gorm db data type.
func (BinUUID) GormDataType ¶
func (BinUUID) IsEmpty ¶
IsEmpty returns true if BinUUID is nil uuid or of zero length, false otherwise.
func (*BinUUID) IsEmptyPtr ¶
IsEmptyPtr returns true if caller BinUUID ptr is nil or it's value is empty.
func (BinUUID) LengthBytes ¶
Length returns the number of characters in string form of UUID.
func (BinUUID) MarshalJSON ¶
func (*BinUUID) UnmarshalJSON ¶
type PageMoreResp ¶
type PageReq ¶
type PageReq struct {
Page int `json:"page" form:"page" uri:"page"`
PageSize int `json:"page_size" form:"page_size" uri:"page_size"`
}
Click to show internal directories.
Click to hide internal directories.